@@ -29,4 +29,4 @@ from upplib.markdown import *
 # 多线程处理类的数据
 from upplib.multi_thread import *
 
-from upplib.fun_util import *
+from upplib.query_log import *
