@@ -101,9 +101,8 @@ def get_trace_id_from_txt(file_name: str = 'a.txt',
             if trace_id_type == 1:
                 try:
                     if ' - ' in trace_id_line:
-                        trace_id = trace_id_line[0:130].split(' - ')[0].split(' ')[-1].strip()
-                        if 15 <= len(trace_id) <= 55 and len(trace_id.split('-')) >= 3:
-                            trace_id_ids.add(trace_id)
+                        trace_id = trace_id_line[0:130].split(' - ')[1].strip()
+                        trace_id_ids.add(trace_id)
                 except Exception as e:
                     continue
     r_list = list(trace_id_ids)
